@@ -1,6 +1,18 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
+"""
+n Asset Relationship is a link between an asset and any other data entity which
+is identifiable by a unique ID. Each relationship contains an Asset ID and a
+Related ID, as well as a Relationship Type. These are used to model relationships
+with both external sources (such as Scenes and Objects), and between assets
+(such as having one Asset be the thumbnail of another).
+
+:asset: The ID of the Asset specified in the Relationship.
+:related: The ID of the Related entity in the Relationship.
+:type: The type of Relationship (ie. "scene", "property", "object", etc).
+"""
+
 """
 Apache2 License Notice
 Copyright 2018 Alex Barry
@@ -18,9 +30,6 @@ limitations under the License.
 import copy
 
 class AeselAssetRelationship(object):
-    """
-    Data Model for Asset Relationship.
-    """
     def __init__(self):
         self.asset = None
         self.related = None
